@@ -1,6 +1,6 @@
 """Mongo repository implementation."""
 
-from typing import Any, AnyStr, List, NoReturn
+from typing import Any, AnyStr, List, NoReturn, Type, Optional
 
 from pydbrepo.drivers import Mongo, MongoAction, MongoActionType
 from pydbrepo.entity import Entity
@@ -15,7 +15,7 @@ class MongoRepository(Repository):
 
     :param driver: Database driver implementation
     :param collection: Main table that will handle the repository
-    :param entity: Base data entity that will handle the repository
+    :param entity: Class type that should be handled by the repository
     :param log_level: Logging level
     :param debug: Flag for debug mode
     :param auto_timestamps: Flag to insert timestamps on configured created_at and updated_at fields
@@ -26,13 +26,13 @@ class MongoRepository(Repository):
     def __init__(
         self,
         driver: Mongo,
-        collection: AnyStr = None,
-        entity: Entity = None,
-        log_level: int = None,
-        debug: bool = False,
-        auto_timestamps: bool = False,
-        created_at: AnyStr = None,
-        updated_at: AnyStr = None,
+        collection: Optional[AnyStr] = None,
+        entity: Optional[Type] = None,
+        log_level: Optional[int] = None,
+        debug: Optional[bool] = False,
+        auto_timestamps: Optional[bool] = False,
+        created_at: Optional[AnyStr] = None,
+        updated_at: Optional[AnyStr] = None,
     ):
         super().__init__(driver, entity, log_level, debug, auto_timestamps, created_at, updated_at)
         self._collection = collection
